Package: DT
Type: Package
Title: A Wrapper of the JavaScript Library 'DataTables'
Version: 0.4
Authors@R: c(
    person("Yihui", "Xie", email = "xie@yihui.name", role = c("aut", "cre")),
    person("Joe", "Cheng", role = "ctb"),
    person("JJ", "Allaire", role = "ctb"),
    person("Xianying", "Tan", role = "ctb"),
    person("Maximilian", "Girlich", role = "ctb"),
    person("jQuery contributors", role = c("ctb", "cph"), comment = "jQuery in htmlwidgets/lib"),
    person("SpryMedia Limited", role = c("ctb", "cph"), comment = "DataTables in htmlwidgets/lib"),
    person("Brian", "Reavis", role = c("ctb", "cph"), comment = "selectize.js in htmlwidgets/lib"),
    person("Leon", "Gersen", role = c("ctb", "cph"), comment = "noUiSlider in htmlwidgets/lib"),
    person("Bartek", "Szopka", role = c("ctb", "cph"), comment = "jquery.highlight.js in htmlwidgets/lib"),
    person("RStudio Inc", role = "cph")
    )
Maintainer: Yihui Xie <xie@yihui.name>
Description: Data objects in R can be rendered as HTML tables using the
    JavaScript library 'DataTables' (typically via R Markdown or Shiny). The
    'DataTables' library has been included in this R package. The package name
    'DT' is an abbreviation of 'DataTables'.
URL: https://rstudio.github.io/DT
BugReports: https://github.com/rstudio/DT/issues
License: GPL-3 | file LICENSE
Imports: htmltools (>= 0.3.6), htmlwidgets (>= 1.0), magrittr,
        crosstalk
Suggests: jsonlite (>= 0.9.16), knitr (>= 1.8), rmarkdown, shiny (>=
        0.12.1)
VignetteBuilder: knitr
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-01-30 21:06:51 UTC; yihui
Author: Yihui Xie [aut, cre],
  Joe Cheng [ctb],
  JJ Allaire [ctb],
  Xianying Tan [ctb],
  Maximilian Girlich [ctb],
  jQuery contributors [ctb, cph] (jQuery in htmlwidgets/lib),
  SpryMedia Limited [ctb, cph] (DataTables in htmlwidgets/lib),
  Brian Reavis [ctb, cph] (selectize.js in htmlwidgets/lib),
  Leon Gersen [ctb, cph] (noUiSlider in htmlwidgets/lib),
  Bartek Szopka [ctb, cph] (jquery.highlight.js in htmlwidgets/lib),
  RStudio Inc [cph]
Repository: CRAN
Date/Publication: 2018-01-30 22:54:05 UTC
Built: R 3.3.2; ; 2018-03-10 16:45:31 UTC; windows
